@@ -38,7 +38,7 @@ class Domoticz(IPlugin):
 		if entity == "dz_loc_bureau_deux" or entity == "dz_loc_bureau_un" or entity == "dz_loc_carrillon" or entity == "dz_loc_salon"  :
 			on_off = jsonInput['outcome']['entities']['on_off']['value']
 			location = "VIDE"
-		if entity ="dz_loc_frisquet"  :
+		if entity == "dz_loc_frisquet"  :
 			on_off = jsonInput['outcome']['entities']['on_off']['value']
 			location = jsonInput['outcome']['entities']['location']['body']
 		idex= location + "_" + on_off
